pub enum HDF5Error {
Show 23 variants
InvalidSignature {
offset: u64,
hint: String,
},
UnsupportedSuperblockVersion(u8),
UnsupportedObjectHeaderVersion(u8),
UnsupportedDataLayoutVersion(u8),
UnsupportedDatatypeClass(u8),
UnsupportedFilterPipelineVersion(u8),
UnsupportedChunkIndexingType(u8),
UnsupportedBTreeVersion(u8),
InvalidBTreeSignature {
expected: String,
got: String,
},
UnsupportedHeapVersion(u8),
InvalidHeapSignature {
expected: String,
got: String,
},
NotFound(String),
NotAGroup(String),
NotADataset(String),
UnexpectedEof {
needed: usize,
available: usize,
},
UndefinedAddress,
InvalidObjectHeaderSignature,
UnsupportedLinkType(u8),
UnsupportedMessageType(u16),
Io(Error),
General(String),
ObjectStore(Error),
Reqwest(Error),
}Expand description
Errors that can occur when reading HDF5 files.
Variants
InvalidSignature
The file does not have a valid HDF5 signature.
Fields
UnsupportedSuperblockVersion(u8)
The superblock version is not supported.
UnsupportedObjectHeaderVersion(u8)
The object header version is not supported.
UnsupportedDataLayoutVersion(u8)
The data layout message version is not supported.
UnsupportedDatatypeClass(u8)
The datatype class is not supported.
UnsupportedFilterPipelineVersion(u8)
The filter pipeline version is not supported.
UnsupportedChunkIndexingType(u8)
The chunk indexing type is not supported.
UnsupportedBTreeVersion(u8)
The B-tree version is not supported.
InvalidBTreeSignature
The B-tree signature does not match what was expected.
UnsupportedHeapVersion(u8)
The heap version is not supported.
InvalidHeapSignature
The heap signature does not match what was expected.
NotFound(String)
A group member was not found at the given path.
NotAGroup(String)
The path does not point to a group.
NotADataset(String)
The path does not point to a dataset.
UnexpectedEof
The data ended before the expected number of bytes could be read.
UndefinedAddress
An undefined address was encountered (unallocated storage).
InvalidObjectHeaderSignature
The object header signature is invalid.
UnsupportedLinkType(u8)
The link type is not supported.
UnsupportedMessageType(u16)
The message type is not supported.
Io(Error)
An I/O error occurred.
General(String)
A general error with a descriptive message.
ObjectStore(Error)
An object store error occurred.
Reqwest(Error)
An HTTP request error occurred.