ExtensibleArrayHeader

Struct ExtensibleArrayHeader 

pub struct ExtensibleArrayHeader {
    pub client_id: u8,
    pub element_size: u8,
    pub max_nelmts_bits: u8,
    pub idx_blk_elmts: u8,
    pub data_blk_min_elmts: u8,
    pub sup_blk_min_data_ptrs: u8,
    pub max_dblk_page_nelmts_bits: u8,
    pub index_block_address: u64,
    pub nsblks: usize,
    pub sblk_info: Vec<SBlockInfo>,
    pub dblk_page_nelmts: usize,
    pub arr_off_size: u8,
}
Parsed Extensible Array header (EAHD).

Fields

client_id: u8

Client ID: 0 = non-filtered chunks, 1 = filtered chunks.

element_size: u8

Size of each element in bytes.

max_nelmts_bits: u8

Number of bits needed to store the max number of elements.

idx_blk_elmts: u8

Number of elements stored directly in the index block.

data_blk_min_elmts: u8

Minimum number of elements per data block.

sup_blk_min_data_ptrs: u8

Minimum number of data block pointers per super block.

max_dblk_page_nelmts_bits: u8

Log2 of max elements per data block page.

index_block_address: u64

Address of the index block.

nsblks: usize

Total number of super block levels.

sblk_info: Vec<SBlockInfo>

Info for each super block level.

dblk_page_nelmts: usize

Number of elements per data block page (0 means no paging).

arr_off_size: u8

Byte width of array offset fields in EASB/EADB.

Implementations

Source

impl ExtensibleArrayHeader

pub async fn read( reader: &Arc<dyn AsyncFileReader>, address: u64, size_of_offsets: u8, size_of_lengths: u8, ) -> Result<Self>

Read and parse an Extensible Array header from the given address.