pub struct SBlockInfo {
pub ndblks: usize,
pub dblk_nelmts: usize,
pub start_idx: u64,
}Expand description
Pre-computed information for a single super block level.
Fields
ndblks: usizeNumber of data blocks at this super block level.
dblk_nelmts: usizeNumber of elements in each data block at this level.
start_idx: u64Index of the first element covered by this super block level.