pub struct ExtensibleArrayHeader {
pub client_id: u8,
pub element_size: u8,
pub max_nelmts_bits: u8,
pub idx_blk_elmts: u8,
pub data_blk_min_elmts: u8,
pub sup_blk_min_data_ptrs: u8,
pub max_dblk_page_nelmts_bits: u8,
pub index_block_address: u64,
pub nsblks: usize,
pub sblk_info: Vec<SBlockInfo>,
pub dblk_page_nelmts: usize,
pub arr_off_size: u8,
}Expand description
Parsed Extensible Array header (EAHD).
Fields
client_id: u8Client ID: 0 = non-filtered chunks, 1 = filtered chunks.
element_size: u8Size of each element in bytes.
max_nelmts_bits: u8Number of bits needed to store the max number of elements.
idx_blk_elmts: u8Number of elements stored directly in the index block.
data_blk_min_elmts: u8Minimum number of elements per data block.
sup_blk_min_data_ptrs: u8Minimum number of data block pointers per super block.
max_dblk_page_nelmts_bits: u8Log2 of max elements per data block page.
index_block_address: u64Address of the index block.
nsblks: usizeTotal number of super block levels.
sblk_info: Vec<SBlockInfo>Info for each super block level.
dblk_page_nelmts: usizeNumber of elements per data block page (0 means no paging).
arr_off_size: u8Byte width of array offset fields in EASB/EADB.
Implementations